@@ -1,3 +1,4 @@
+#define USE_FC_LEN_T
 #include <algorithm>
 #include <string>
 #include <R.h>
@@ -7,6 +8,9 @@
 #include <R_ext/Lapack.h>
 #include <R_ext/BLAS.h>
 #include "util.h"
+#ifndef FCONE
+# define FCONE
+#endif
 
 extern "C" {
 
@@ -205,18 +209,18 @@ extern "C" {
     double *gamma = (double *) R_alloc(3, sizeof(double)); //sigma^2, phi, nu
 
     //Sigma_0^{-1}
-    F77_NAME(dpotrf)(lower, &p, sigma0, &p, &info); if(info != 0){error("c++ error: dpotrf failed 0\n");}
-    F77_NAME(dpotri)(lower, &p, sigma0, &p, &info); if(info != 0){error("c++ error: dpotri failed 0.5\n");}
+    F77_NAME(dpotrf)(lower, &p, sigma0, &p, &info FCONE); if(info != 0){error("c++ error: dpotrf failed 0\n");}
+    F77_NAME(dpotri)(lower, &p, sigma0, &p, &info FCONE); if(info != 0){error("c++ error: dpotri failed 0.5\n");}
 
     //X'_tX_t
     double *XX = (double *) R_alloc(Nt*pp, sizeof(double));
     for(t = 0; t < Nt; t++){
-      F77_NAME(dgemm)(ntran, ytran, &p, &p, &n, &one, &X[t*n*p], &p, &X[t*n*p], &p, &zero, &XX[t*pp], &p); 
+      F77_NAME(dgemm)(ntran, ytran, &p, &p, &n, &one, &X[t*n*p], &p, &X[t*n*p], &p, &zero, &XX[t*pp], &p FCONE FCONE); 
     }
     
     //SigmaEtaIW_S is Upsilon^{-1}
-    F77_NAME(dpotrf)(lower, &p, SigmaEtaIW_S, &p, &info); if(info != 0){error("c++ error: dpotrf failed 1.1\n");}
-    F77_NAME(dpotri)(lower, &p, SigmaEtaIW_S, &p, &info); if(info != 0){error("c++ error: dpotri failed 2.01\n");}
+    F77_NAME(dpotrf)(lower, &p, SigmaEtaIW_S, &p, &info FCONE); if(info != 0){error("c++ error: dpotrf failed 1.1\n");}
+    F77_NAME(dpotri)(lower, &p, SigmaEtaIW_S, &p, &info FCONE); if(info != 0){error("c++ error: dpotri failed 2.01\n");}
 
     if(verbose){
       Rprintf("-------------------------------------------------\n");
@@ -232,23 +236,23 @@ extern "C" {
     for(s = 0; s < nSamples; s++){
 
       //Sigma_eta^{-1}
-      F77_NAME(dpotrf)(lower, &p, sigmaEta, &p, &info); if(info != 0){error("c++ error: dpotrf1 failed\n");}
-      F77_NAME(dpotri)(lower, &p, sigmaEta, &p, &info); if(info != 0){error("c++ error: dpotri failed\n");}
+      F77_NAME(dpotrf)(lower, &p, sigmaEta, &p, &info FCONE); if(info != 0){error("c++ error: dpotrf1 failed\n");}
+      F77_NAME(dpotri)(lower, &p, sigmaEta, &p, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
 
       //update Beta_0
       F77_NAME(dcopy)(&pp, sigmaEta, &incOne, tmp_pp, &incOne);
       F77_NAME(daxpy)(&pp, &one, sigma0, &incOne, tmp_pp, &incOne);
 
       //Sigma_Beta0
-      F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info); if(info != 0){error("c++ error: dpotrf2 failed\n");}
-      F77_NAME(dpotri)(lower, &p, tmp_pp, &p, &info); if(info != 0){error("c++ error: dpotri failed\n");}
+      F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){error("c++ error: dpotrf2 failed\n");}
+      F77_NAME(dpotri)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
 
       //mu_Beta0
-      F77_NAME(dsymv)(lower, &p, &one, sigma0, &p, m0, &incOne, &zero, tmp_p, &incOne);
-      F77_NAME(dsymv)(lower, &p, &one, sigmaEta, &p, beta, &incOne, &one, tmp_p, &incOne);//first column of beta is Beta_1
-      F77_NAME(dsymv)(lower, &p, &one, tmp_pp, &p, tmp_p, &incOne, &zero, tmp_p2, &incOne); 
+      F77_NAME(dsymv)(lower, &p, &one, sigma0, &p, m0, &incOne, &zero, tmp_p, &incOne FCONE);
+      F77_NAME(dsymv)(lower, &p, &one, sigmaEta, &p, beta, &incOne, &one, tmp_p, &incOne FCONE);//first column of beta is Beta_1
+      F77_NAME(dsymv)(lower, &p, &one, tmp_pp, &p, tmp_p, &incOne, &zero, tmp_p2, &incOne FCONE); 
 
-     F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info); if(info != 0){error("c++ error: dpotrf3 failed\n");}
+     F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){error("c++ error: dpotrf3 failed\n");}
      mvrnorm(beta0, tmp_p2, tmp_pp, p);
 
      F77_NAME(dcopy)(&p, beta0, &incOne, &beta0Samples[s*p], &incOne);
@@ -258,7 +262,7 @@ extern "C" {
      ////////////////////
      if(anyMissing || getFitted){
        for(t = 0, j = 0; t < Nt; t++){
-	 F77_NAME(dgemv)(ytran, &p, &n, &one, &X[t*n*p], &p, &beta[t*p], &incOne, &zero, tmp_n3, &incOne);
+	 F77_NAME(dgemv)(ytran, &p, &n, &one, &X[t*n*p], &p, &beta[t*p], &incOne, &zero, tmp_n3, &incOne FCONE);
 	 for(i = 0; i < n; i++, j++){
 	   if(missing[j] == 1){
 	     Y[n*t+i] = rnorm(tmp_n3[i] + u[n*t+i], sqrt(theta[t*nTheta+tauSqIndx]));
@@ -288,14 +292,14 @@ extern "C" {
        tmp = 1.0/theta[t*nTheta+tauSqIndx]; 
        F77_NAME(daxpy)(&pp, &tmp, &XX[t*pp], &incOne, tmp_pp, &incOne);
    
-       F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info); if(info != 0){error("c++ error: dpotrf4 failed\n");}
-       F77_NAME(dpotri)(lower, &p, tmp_pp, &p, &info); if(info != 0){error("c++ error: dpotri failed\n");}
+       F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){error("c++ error: dpotrf4 failed\n");}
+       F77_NAME(dpotri)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
        
        //mu_Beta_t
        for(i = 0; i < n; i++){
 	 tmp_n[i] = (Y[n*t+i] - u[n*t+i])*tmp;
        }
-       F77_NAME(dgemv)(ntran, &p, &n, &one, &X[t*n*p], &p, tmp_n, &incOne, &zero, tmp_p, &incOne);
+       F77_NAME(dgemv)(ntran, &p, &n, &one, &X[t*n*p], &p, tmp_n, &incOne, &zero, tmp_p, &incOne FCONE);
        
        if(t == 0){
 	 for(i = 0; i < p; i++){
@@ -309,10 +313,10 @@ extern "C" {
 	 }
        }
 
-       F77_NAME(dsymv)(lower, &p, &one, sigmaEta, &p, tmp_p2, &incOne, &one, tmp_p, &incOne); 
-       F77_NAME(dsymv)(lower, &p, &one, tmp_pp, &p, tmp_p, &incOne, &zero, tmp_p2, &incOne); 
+       F77_NAME(dsymv)(lower, &p, &one, sigmaEta, &p, tmp_p2, &incOne, &one, tmp_p, &incOne FCONE); 
+       F77_NAME(dsymv)(lower, &p, &one, tmp_pp, &p, tmp_p, &incOne, &zero, tmp_p2, &incOne FCONE); 
 
-       F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info); if(info != 0){error("c++ error: dpotrf5 failed\n");}
+       F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){error("c++ error: dpotrf5 failed\n");}
        mvrnorm(&beta[t*p], tmp_p2, tmp_pp, p);
 
        ////////////////////
@@ -326,10 +330,10 @@ extern "C" {
 	 
        spCovLT(coordsD, n, gamma, covModel, C);
     
-       F77_NAME(dpotrf)(lower, &n, C, &n, &info); if(info != 0){error("c++ error: dpotrf6 failed\n");}
-       F77_NAME(dpotri)(lower, &n, C, &n, &info); if(info != 0){error("c++ error: dpotri failed\n");}
+       F77_NAME(dpotrf)(lower, &n, C, &n, &info FCONE); if(info != 0){error("c++ error: dpotrf6 failed\n");}
+       F77_NAME(dpotri)(lower, &n, C, &n, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
 
-       F77_NAME(dgemv)(ytran, &p, &n, &one, &X[t*n*p], &p, &beta[t*p], &incOne, &zero, tmp_n3, &incOne);
+       F77_NAME(dgemv)(ytran, &p, &n, &one, &X[t*n*p], &p, &beta[t*p], &incOne, &zero, tmp_n3, &incOne FCONE);
 
        if(t < (Nt-1)){
 
@@ -342,14 +346,14 @@ extern "C" {
 	 
        	 spCovLT(coordsD, n, gamma, covModel, C2);
 	 
-       	 F77_NAME(dpotrf)(lower, &n, C2, &n, &info); if(info != 0){error("c++ error: dpotrf7 failed\n");}
-       	 F77_NAME(dpotri)(lower, &n, C2, &n, &info); if(info != 0){error("c++ error: dpotri failed\n");}
+       	 F77_NAME(dpotrf)(lower, &n, C2, &n, &info FCONE); if(info != 0){error("c++ error: dpotrf7 failed\n");}
+       	 F77_NAME(dpotri)(lower, &n, C2, &n, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
 	 
        	 //mu
-       	 F77_NAME(dsymv)(lower, &n, &one, C2, &n, &u[(t+1)*n], &incOne, &zero, tmp_n, &incOne);
+       	 F77_NAME(dsymv)(lower, &n, &one, C2, &n, &u[(t+1)*n], &incOne, &zero, tmp_n, &incOne FCONE);
 
        	 if(t > 0){
-       	   F77_NAME(dsymv)(lower, &n, &one, C, &n, &u[(t-1)*n], &incOne, &one, tmp_n, &incOne);
+       	   F77_NAME(dsymv)(lower, &n, &one, C, &n, &u[(t-1)*n], &incOne, &one, tmp_n, &incOne FCONE);
        	 }
 	 
        	 for(i = 0; i < n; i++){
@@ -363,13 +367,13 @@ extern "C" {
        	   C2[i*n+i] += tmp;
        	 }
 	 
-       	 F77_NAME(dpotrf)(lower, &n, C2, &n, &info); if(info != 0){error("c++ error: dpotrf8 failed\n");}
-       	 F77_NAME(dpotri)(lower, &n, C2, &n, &info); if(info != 0){error("c++ error: dpotri failed\n");}
+       	 F77_NAME(dpotrf)(lower, &n, C2, &n, &info FCONE); if(info != 0){error("c++ error: dpotrf8 failed\n");}
+       	 F77_NAME(dpotri)(lower, &n, C2, &n, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
 	 	 
        	 //finish mu
-       	 F77_NAME(dsymv)(lower, &n, &one, C2, &n, tmp_n, &incOne, &zero, tmp_n2, &incOne);
+       	 F77_NAME(dsymv)(lower, &n, &one, C2, &n, tmp_n, &incOne, &zero, tmp_n2, &incOne FCONE);
 
-       	 F77_NAME(dpotrf)(lower, &n, C2, &n, &info); if(info != 0){error("c++ error: dpotrf9 failed\n");}
+       	 F77_NAME(dpotrf)(lower, &n, C2, &n, &info FCONE); if(info != 0){error("c++ error: dpotrf9 failed\n");}
        	 mvrnorm(&u[t*n], tmp_n2, C2, n);
 
        }else{//t==Nt
@@ -377,7 +381,7 @@ extern "C" {
        	 F77_NAME(dcopy)(&nn, C, &incOne, C2, &incOne);
 
        	 //mu
-       	 F77_NAME(dsymv)(lower, &n, &one, C2, &n, &u[(t-1)*n], &incOne, &zero, tmp_n, &incOne);
+       	 F77_NAME(dsymv)(lower, &n, &one, C2, &n, &u[(t-1)*n], &incOne, &zero, tmp_n, &incOne FCONE);
 
        	 for(i = 0; i < n; i++){
        	   tmp_n[i] += (Y[t*n+i] - tmp_n3[i])*tmp;
@@ -388,13 +392,13 @@ extern "C" {
        	   C2[i*n+i] += tmp;
        	 }
 	 
-       	 F77_NAME(dpotrf)(lower, &n, C2, &n, &info); if(info != 0){error("c++ error: dpotrf10 failed\n");}
-       	 F77_NAME(dpotri)(lower, &n, C2, &n, &info); if(info != 0){error("c++ error: dpotri failed\n");}
+       	 F77_NAME(dpotrf)(lower, &n, C2, &n, &info FCONE); if(info != 0){error("c++ error: dpotrf10 failed\n");}
+       	 F77_NAME(dpotri)(lower, &n, C2, &n, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
 	 
        	 //finish mu	 
-       	 F77_NAME(dsymv)(lower, &n, &one, C2, &n, tmp_n, &incOne, &zero, tmp_n2, &incOne);
+       	 F77_NAME(dsymv)(lower, &n, &one, C2, &n, tmp_n, &incOne, &zero, tmp_n2, &incOne FCONE);
 	 
-       	 F77_NAME(dpotrf)(lower, &n, C2, &n, &info); if(info != 0){error("c++ error: dpotrf11 failed\n");}
+       	 F77_NAME(dpotrf)(lower, &n, C2, &n, &info FCONE); if(info != 0){error("c++ error: dpotrf11 failed\n");}
        	 mvrnorm(&u[t*n], tmp_n2, C2, n);
        }
  
@@ -417,7 +421,7 @@ extern "C" {
        	 }
        }
 
-       F77_NAME(dsymv)(lower, &n, &one, C, &n, tmp_n, &incOne, &zero, tmp_n2, &incOne);
+       F77_NAME(dsymv)(lower, &n, &one, C, &n, tmp_n, &incOne, &zero, tmp_n2, &incOne FCONE);
        
        theta[t*nTheta+sigmaSqIndx] = 1.0/rgamma(sigmaSqIG[t*2]+n/2.0, 
        						1.0/(sigmaSqIG[t*2+1]+0.5*F77_NAME(ddot)(&n, tmp_n, &incOne, tmp_n2, &incOne)*theta[t*nTheta+sigmaSqIndx]));
@@ -443,11 +447,11 @@ extern "C" {
        spCovLT(coordsD, n, gamma, covModel, C);
        
        logDet = 0;
-       F77_NAME(dpotrf)(lower, &n, C, &n, &info); if(info != 0){error("c++ error: dpotrf12 failed\n");}
+       F77_NAME(dpotrf)(lower, &n, C, &n, &info FCONE); if(info != 0){error("c++ error: dpotrf12 failed\n");}
        for(i = 0; i < n; i++) logDet += 2*log(C[i*n+i]);
-       F77_NAME(dpotri)(lower, &n, C, &n, &info); if(info != 0){error("c++ error: dpotri failed\n");}
+       F77_NAME(dpotri)(lower, &n, C, &n, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
 	 
-       F77_NAME(dsymv)(lower, &n, &one, C, &n, tmp_n, &incOne, &zero, tmp_n2, &incOne);
+       F77_NAME(dsymv)(lower, &n, &one, C, &n, tmp_n, &incOne, &zero, tmp_n2, &incOne FCONE);
        logPost = -0.5*logDet-0.5*F77_NAME(ddot)(&n, tmp_n, &incOne, tmp_n2, &incOne);
 
        logPost += log(gamma[1] - phiUnif[t*2]) + log(phiUnif[t*2+1] - gamma[1]);
@@ -465,11 +469,11 @@ extern "C" {
        spCovLT(coordsD, n, gamma, covModel, C);
        
        logDetCand = 0;
-       F77_NAME(dpotrf)(lower, &n, C, &n, &info); if(info != 0){error("c++ error: dpotrf13 failed\n");}
+       F77_NAME(dpotrf)(lower, &n, C, &n, &info FCONE); if(info != 0){error("c++ error: dpotrf13 failed\n");}
        for(i = 0; i < n; i++) logDetCand += 2*log(C[i*n+i]);
-       F77_NAME(dpotri)(lower, &n, C, &n, &info); if(info != 0){error("c++ error: dpotri failed\n");}
+       F77_NAME(dpotri)(lower, &n, C, &n, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
        
-       F77_NAME(dsymv)(lower, &n, &one, C, &n, tmp_n, &incOne, &zero, tmp_n2, &incOne);
+       F77_NAME(dsymv)(lower, &n, &one, C, &n, tmp_n, &incOne, &zero, tmp_n2, &incOne FCONE);
        logPostCand = -0.5*logDetCand-0.5*F77_NAME(ddot)(&n, tmp_n, &incOne, tmp_n2, &incOne);
        
        logPostCand += log(gamma[1] - phiUnif[t*2]) + log(phiUnif[t*2+1] - gamma[1]);
@@ -499,21 +503,21 @@ extern "C" {
      for(i = 0; i < p; i++){
        tmp_p[i] = beta[i]-beta0[i];
      }
-     F77_NAME(dgemm)(ntran, ytran, &p, &p, &incOne, &one, tmp_p, &p, tmp_p, &p, &zero, tmp_pp, &p); 
+     F77_NAME(dgemm)(ntran, ytran, &p, &p, &incOne, &one, tmp_p, &p, tmp_p, &p, &zero, tmp_pp, &p FCONE FCONE); 
      
      for(t = 1; t < Nt; t++){
        for(i = 0; i < p; i++){
      	 tmp_p[i] = beta[p*t+i]-beta[p*(t-1)+i];
        }
-       F77_NAME(dgemm)(ntran, ytran, &p, &p, &incOne, &one, tmp_p, &p, tmp_p, &p, &one, tmp_pp, &p); 
+       F77_NAME(dgemm)(ntran, ytran, &p, &p, &incOne, &one, tmp_p, &p, tmp_p, &p, &one, tmp_pp, &p FCONE FCONE); 
      }
 
      F77_NAME(daxpy)(&pp, &one, SigmaEtaIW_S, &incOne, tmp_pp, &incOne);
      
      rwish(tmp_pp, SigmaEtaIW_df+Nt, p, sigmaEta, tmp_pp2, 1);
 
-     // F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info); if(info != 0){error("c++ error: dpotrf failed\n");}
-     // F77_NAME(dpotri)(lower, &p, tmp_pp, &p, &info); if(info != 0){error("c++ error: dpotri failed\n");}
+     // F77_NAME(dpotrf)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}
+     // F77_NAME(dpotri)(lower, &p, tmp_pp, &p, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
      
      // for(i = 1; i < p; i++){
      //   for(j = 0; j < i; j++){
