@@ -1,3 +1,4 @@
+#define USE_FC_LEN_T
 #include <string>
 #include <R.h>
 #include <Rmath.h>
@@ -6,6 +7,9 @@
 #include <R_ext/Lapack.h>
 #include <R_ext/BLAS.h>
 #include "util.h"
+#ifndef FCONE
+# define FCONE
+#endif
 
 extern "C" {
 
@@ -258,9 +262,9 @@ extern "C" {
       
       //invert C and log det cov
       detCand = 0;
-      F77_NAME(dpotrf)(lower, &n, C, &n, &info); if(info != 0){error("c++ error: dpotrf failed\n");}
+      F77_NAME(dpotrf)(lower, &n, C, &n, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}
       for(i = 0; i < n; i++) detCand += 2*log(C[i*n+i]);
-      F77_NAME(dpotri)(lower, &n, C, &n, &info); if(info != 0){error("c++ error: dpotri failed\n");}
+      F77_NAME(dpotri)(lower, &n, C, &n, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
       
       //Likelihood with Jacobian  
       logPostCand = 0.0;
@@ -279,7 +283,7 @@ extern "C" {
 	logPostCand += log(nu - nuUnifa) + log(nuUnifb - nu);   
       }
 
-      F77_NAME(dgemv)(ntran, &n, &p, &one, X, &n, beta, &incOne, &zero, tmp_n, &incOne);
+      F77_NAME(dgemv)(ntran, &n, &p, &one, X, &n, beta, &incOne, &zero, tmp_n, &incOne FCONE);
       
       if(family == "binomial"){
 	logPostCand += binomial_logpost(n, Y, tmp_n, wCand, weights);
@@ -290,7 +294,7 @@ extern "C" {
       }
 
       //(-1/2) * tmp_n` *  C^-1 * tmp_n
-      F77_NAME(dsymv)(lower, &n, &one,  C, &n, wCand, &incOne, &zero, tmp_n1, &incOne);
+      F77_NAME(dsymv)(lower, &n, &one,  C, &n, wCand, &incOne, &zero, tmp_n1, &incOne FCONE);
       logPostCand += -0.5*detCand-0.5*F77_NAME(ddot)(&n, wCand, &incOne, tmp_n1, &incOne);
 
       //
