@@ -1,3 +1,4 @@
+#define USE_FC_LEN_T
 #include <string>
 #include <R.h>
 #include <Rinternals.h>
@@ -5,6 +6,9 @@
 #include <R_ext/Lapack.h>
 #include <R_ext/BLAS.h>
 #include "util.h"
+#ifndef FCONE
+# define FCONE
+#endif
 
 extern"C" {
 
@@ -47,7 +51,7 @@ extern"C" {
   
   //Get A
   F77_NAME(dcopy)(&mm, REAL(V_r), &incOne, A, &incOne);
-  F77_NAME(dpotrf)(lower, &m, A, &m, &info); if(info != 0){error("c++ error: dpotrf failed 1\n");}
+  F77_NAME(dpotrf)(lower, &m, A, &m, &info FCONE); if(info != 0){error("c++ error: dpotrf failed 1\n");}
 
   SEXP D_r;
   PROTECT(D_r = allocVector(REALSXP, 1)); 
@@ -92,12 +96,12 @@ extern"C" {
     }
   }
 
-  F77_NAME(dpotrf)(lower, &qm, C_str, &qm, &info); if(info != 0){error("c++ error: dpotrf failed 2\n");}
-  F77_NAME(dpotri)(lower, &qm, C_str, &qm, &info); if(info != 0){error("c++ error: dpotri failed 3\n");}
+  F77_NAME(dpotrf)(lower, &qm, C_str, &qm, &info FCONE); if(info != 0){error("c++ error: dpotrf failed 2\n");}
+  F77_NAME(dpotri)(lower, &qm, C_str, &qm, &info FCONE); if(info != 0){error("c++ error: dpotri failed 3\n");}
   
   //C = ct C_str^{-1} t(ct)
-  F77_NAME(dsymm)(rside, lower, &nm, &qm, &one, C_str, &qm, ct, &nm, &zero, tmp_nmqm, &nm);
-  F77_NAME(dgemm)(ntran, ytran, &nm, &nm, &qm, &one, tmp_nmqm, &nm, ct, &nm, &zero, C, &nm);
+  F77_NAME(dsymm)(rside, lower, &nm, &qm, &one, C_str, &qm, ct, &nm, &zero, tmp_nmqm, &nm FCONE FCONE);
+  F77_NAME(dgemm)(ntran, ytran, &nm, &nm, &qm, &one, tmp_nmqm, &nm, ct, &nm, &zero, C, &nm FCONE FCONE);
     
   for(i = 0; i < n; i++){
     
@@ -109,11 +113,11 @@ extern"C" {
     
     F77_NAME(dcopy)(&mm, tmp_mm, &incOne, &REAL(CEps_r)[i*mm], &incOne);
 
-    F77_NAME(dpotrf)(lower, &m, tmp_mm, &m, &info); if(info != 0){error("c++ error: dpotrf failed 4\n");}
+    F77_NAME(dpotrf)(lower, &m, tmp_mm, &m, &info FCONE); if(info != 0){error("c++ error: dpotrf failed 4\n");}
     for(j = 0; j < m; j++) logDet += 2.0*log(tmp_mm[j*m+j]);
-    F77_NAME(dpotri)(lower, &m, tmp_mm, &m, &info); if(info != 0){error("c++ error: dpotri failed 5\n");}
+    F77_NAME(dpotri)(lower, &m, tmp_mm, &m, &info FCONE); if(info != 0){error("c++ error: dpotri failed 5\n");}
      
-    F77_NAME(dsymv)(lower, &m, &one, tmp_mm, &m, &REAL(Q_r)[i*m], &incOne, &zero, &tmp_nm[i*m], &incOne);
+    F77_NAME(dsymv)(lower, &m, &one, tmp_mm, &m, &REAL(Q_r)[i*m], &incOne, &zero, &tmp_nm[i*m], &incOne FCONE);
   }
   
   REAL(D_r)[0] = logDet+F77_NAME(ddot)(&nm, tmp_nm, &incOne, REAL(Q_r), &incOne);
