@@ -1,3 +1,4 @@
+#define USE_FC_LEN_T
 #include <string>
 #include <R.h>
 #include <Rmath.h>
@@ -6,6 +7,9 @@
 #include <R_ext/Lapack.h>
 #include <R_ext/BLAS.h>
 #include "util.h"
+#ifndef FCONE
+# define FCONE
+#endif
 
 extern "C" {
   
@@ -134,10 +138,10 @@ extern "C" {
       betaCInvMu = (double *) R_alloc(p, sizeof(double));
       
       F77_NAME(dcopy)(&pp, betaC, &incOne, betaCInv, &incOne);
-      F77_NAME(dpotrf)(lower, &p, betaCInv, &p, &info); if(info != 0){error("c++ error: dpotrf failed\n");}
-      F77_NAME(dpotri)(lower, &p, betaCInv, &p, &info); if(info != 0){error("c++ error: dpotri failed\n");}
+      F77_NAME(dpotrf)(lower, &p, betaCInv, &p, &info FCONE); if(info != 0){error("c++ error: dpotrf failed\n");}
+      F77_NAME(dpotri)(lower, &p, betaCInv, &p, &info FCONE); if(info != 0){error("c++ error: dpotri failed\n");}
       
-      F77_NAME(dsymv)(lower, &p, &one, betaCInv, &p, betaMu, &incOne, &zero, betaCInvMu, &incOne);      
+      F77_NAME(dsymv)(lower, &p, &one, betaCInv, &p, betaMu, &incOne, &zero, betaCInvMu, &incOne FCONE);      
     }
     
     if(verbose){
@@ -160,7 +164,7 @@ extern "C" {
     for(s = 0; s < nSamples; s++){
       
       covExpand(&samples[s*nParams+AIndx], A, m);//note this is K, so we need chol
-      F77_NAME(dpotrf)(lower, &m, A, &m, &info); if(info != 0){error("c++ error: dpotrf failed 1\n");} 
+      F77_NAME(dpotrf)(lower, &m, A, &m, &info FCONE); if(info != 0){error("c++ error: dpotrf failed 1\n");} 
       clearUT(A, m); //make sure upper tri is clear
    
       for(k = 0; k < m; k++){
@@ -219,14 +223,14 @@ extern "C" {
 	}
       }
       
-      F77_NAME(dpotrf)(lower, &nm, C, &nm, &info); if(info != 0){error("c++ error: dpotrf failed 2\n");}
+      F77_NAME(dpotrf)(lower, &nm, C, &nm, &info FCONE); if(info != 0){error("c++ error: dpotrf failed 2\n");}
       
       F77_NAME(dcopy)(&nm, Y, &incOne, vU, &incOne);
       F77_NAME(dcopy)(&nmp, X, &incOne, &vU[nm], &incOne);
-      F77_NAME(dtrsm)(lside, lower, ntran, nUnit, &nm, &p1, &one, C, &nm, vU, &nm);//L[v:U] = [y:X]
+      F77_NAME(dtrsm)(lside, lower, ntran, nUnit, &nm, &p1, &one, C, &nm, vU, &nm FCONE FCONE FCONE FCONE);//L[v:U] = [y:X]
       
       //B
-      F77_NAME(dgemm)(ytran, ntran, &p, &p, &nm, &one, &vU[nm], &nm, &vU[nm], &nm, &zero, B, &p); //U'U
+      F77_NAME(dgemm)(ytran, ntran, &p, &p, &nm, &one, &vU[nm], &nm, &vU[nm], &nm, &zero, B, &p FCONE FCONE); //U'U
       
       if(betaPrior == "normal"){
 	for(k = 0; k < p; k++){
@@ -236,11 +240,11 @@ extern "C" {
 	}
       }
       
-      F77_NAME(dpotrf)(lower, &p, B, &p, &info); if(info != 0){error("c++ error: dpotrf failed 3\n");}
-      F77_NAME(dpotri)(lower, &p, B, &p, &info); if(info != 0){error("c++ error: dpotri failed 4\n");}
+      F77_NAME(dpotrf)(lower, &p, B, &p, &info FCONE); if(info != 0){error("c++ error: dpotrf failed 3\n");}
+      F77_NAME(dpotri)(lower, &p, B, &p, &info FCONE); if(info != 0){error("c++ error: dpotri failed 4\n");}
       
       //bb
-      F77_NAME(dgemv)(ytran, &nm, &p, &one, &vU[nm], &nm, vU, &incOne, &zero, tmp_p, &incOne); //U'v
+      F77_NAME(dgemv)(ytran, &nm, &p, &one, &vU[nm], &nm, vU, &incOne, &zero, tmp_p, &incOne FCONE); //U'v
       
       if(betaPrior == "normal"){
 	for(k = 0; k < p; k++){
@@ -248,8 +252,8 @@ extern "C" {
 	}
       }
       
-      F77_NAME(dsymv)(lower, &p, &one, B, &p, tmp_p, &incOne, &zero, bb, &incOne); 
-      F77_NAME(dpotrf)(lower, &p, B, &p, &info); if(info != 0){error("c++ error: dpotrf failed 5\n");}
+      F77_NAME(dsymv)(lower, &p, &one, B, &p, tmp_p, &incOne, &zero, bb, &incOne FCONE); 
+      F77_NAME(dpotrf)(lower, &p, B, &p, &info FCONE); if(info != 0){error("c++ error: dpotrf failed 5\n");}
       
       mvrnorm(&REAL(betaSamples_r)[s*p], bb, B, p, false);
       
@@ -305,13 +309,13 @@ extern "C" {
 	  }
 
 	  //L
-	  F77_NAME(dpotrf)(lower, &nm, C, &nm, &info); if(info != 0){error("c++ error: 1 dpotrf failed\n");}
+	  F77_NAME(dpotrf)(lower, &nm, C, &nm, &info FCONE); if(info != 0){error("c++ error: 1 dpotrf failed\n");}
 
 	  //W
-	  F77_NAME(dtrsm)(lside, lower, ntran, nUnit, &nm, &nm, &one, C, &nm, W, &nm);
+	  F77_NAME(dtrsm)(lside, lower, ntran, nUnit, &nm, &nm, &one, C, &nm, W, &nm FCONE FCONE FCONE FCONE);
 
 	  //L_B
-	  F77_NAME(dgemm)(ytran, ntran, &nm, &nm, &nm, &negOne, W, &nm, W, &nm, &zero, C, &nm);
+	  F77_NAME(dgemm)(ytran, ntran, &nm, &nm, &nm, &negOne, W, &nm, W, &nm, &zero, C, &nm FCONE FCONE);
 
 	  if(PsiDiag){
 	    for(l = 0; l < n; l++){
@@ -329,14 +333,14 @@ extern "C" {
 	    }
 	  }
 
-	  F77_NAME(dpotrf)(lower, &nm, C, &nm, &info); if(info != 0){error("c++ error: 2 dpotrf failed\n");}
+	  F77_NAME(dpotrf)(lower, &nm, C, &nm, &info FCONE); if(info != 0){error("c++ error: 2 dpotrf failed\n");}
 
-	  F77_NAME(dgemv)(ntran, &nm, &p, &negOne, X, &nm, &REAL(betaSamples_r)[s*p], &incOne, &zero, vU, &incOne);
+	  F77_NAME(dgemv)(ntran, &nm, &p, &negOne, X, &nm, &REAL(betaSamples_r)[s*p], &incOne, &zero, vU, &incOne FCONE);
 	  F77_NAME(daxpy)(&nm, &one, Y, &incOne, vU, &incOne);
 
 	  if(!PsiDiag){
-	    F77_NAME(dpotrf)(lower, &m, Psi, &m, &info); if(info != 0){error("c++ error: 3 dpotrf failed 8\n");}
-	    F77_NAME(dpotri)(lower, &m, Psi, &m, &info); if(info != 0){error("c++ error: 4 dpotri failed 9\n");}
+	    F77_NAME(dpotrf)(lower, &m, Psi, &m, &info FCONE); if(info != 0){error("c++ error: 3 dpotrf failed 8\n");}
+	    F77_NAME(dpotri)(lower, &m, Psi, &m, &info FCONE); if(info != 0){error("c++ error: 4 dpotri failed 9\n");}
 	  }
 
 	  for(k = 0; k < n; k++){
@@ -345,18 +349,18 @@ extern "C" {
 	  	vU[nm+k*m+l] = vU[k*m+l]/Psi[l];
 	      }
 	    }else{
-	      F77_NAME(dsymv)(lower, &m, &one, Psi, &m, &vU[k*m], &incOne, &zero, &vU[nm+k*m], &incOne); 
+	      F77_NAME(dsymv)(lower, &m, &one, Psi, &m, &vU[k*m], &incOne, &zero, &vU[nm+k*m], &incOne FCONE); 
 	    }
 	  }
 
-	  F77_NAME(dtrmv)(lower, ytran, nUnit, &nm, C, &nm, &vU[nm], &incOne);
-	  F77_NAME(dtrmv)(lower, ntran, nUnit, &nm, C, &nm, &vU[nm], &incOne);
+	  F77_NAME(dtrmv)(lower, ytran, nUnit, &nm, C, &nm, &vU[nm], &incOne FCONE FCONE FCONE);
+	  F77_NAME(dtrmv)(lower, ntran, nUnit, &nm, C, &nm, &vU[nm], &incOne FCONE FCONE FCONE);
 
 	  for(k = 0; k < nm; k++){
 	    vU[k] = rnorm(0, 1);
 	  }
 
-	  F77_NAME(dtrmv)(lower, ntran, nUnit, &nm, C, &nm, vU, &incOne);
+	  F77_NAME(dtrmv)(lower, ntran, nUnit, &nm, C, &nm, vU, &incOne FCONE FCONE FCONE);
 
 	  for(k = 0; k < nm; k++){
 	    REAL(wSamples_r)[s*nm+k] = vU[nm+k] + vU[k];
@@ -381,8 +385,8 @@ extern "C" {
 	  //   }
 	  // }
 	  
-	  // F77_NAME(dpotrf)(lower, &nm, C, &nm, &info); if(info != 0){error("c++ error: dpotrf failed 6\n");}
-	  // F77_NAME(dpotri)(lower, &nm, C, &nm, &info); if(info != 0){error("c++ error: dpotri failed 7\n");}
+	  // F77_NAME(dpotrf)(lower, &nm, C, &nm, &info FCONE); if(info != 0){error("c++ error: dpotrf failed 6\n");}
+	  // F77_NAME(dpotri)(lower, &nm, C, &nm, &info FCONE); if(info != 0){error("c++ error: dpotri failed 7\n");}
 	  
 	  // if(PsiDiag){
 	  //   for(l = 0; l < n; l++){
@@ -391,8 +395,8 @@ extern "C" {
 	  //     }
 	  //   }
 	  // }else{
-	  //   F77_NAME(dpotrf)(lower, &m, Psi, &m, &info); if(info != 0){error("c++ error: dpotrf failed 8\n");}
-	  //   F77_NAME(dpotri)(lower, &m, Psi, &m, &info); if(info != 0){error("c++ error: dpotri failed 9\n");}
+	  //   F77_NAME(dpotrf)(lower, &m, Psi, &m, &info FCONE); if(info != 0){error("c++ error: dpotrf failed 8\n");}
+	  //   F77_NAME(dpotri)(lower, &m, Psi, &m, &info FCONE); if(info != 0){error("c++ error: dpotri failed 9\n");}
 	    
 	  //   for(i = 0; i < n; i++){
 	  //     for(k = 0; k < m; k++){
@@ -403,10 +407,10 @@ extern "C" {
 	  //   }
 	  // }
 	  
-	  // F77_NAME(dpotrf)(lower, &nm, C, &nm, &info); if(info != 0){error("c++ error: dpotrf failed 10\n");}
-	  // F77_NAME(dpotri)(lower, &nm, C, &nm, &info); if(info != 0){error("c++ error: dpotri failed 11\n");}
+	  // F77_NAME(dpotrf)(lower, &nm, C, &nm, &info FCONE); if(info != 0){error("c++ error: dpotrf failed 10\n");}
+	  // F77_NAME(dpotri)(lower, &nm, C, &nm, &info FCONE); if(info != 0){error("c++ error: dpotri failed 11\n");}
 	  
-	  // F77_NAME(dgemv)(ntran, &nm, &p, &negOne, X, &nm, &REAL(betaSamples_r)[s*p], &incOne, &zero, vU, &incOne);
+	  // F77_NAME(dgemv)(ntran, &nm, &p, &negOne, X, &nm, &REAL(betaSamples_r)[s*p], &incOne, &zero, vU, &incOne FCONE);
 	  // F77_NAME(daxpy)(&nm, &one, Y, &incOne, vU, &incOne);
 	  
 	  // for(k = 0; k < n; k++){
@@ -415,18 +419,18 @@ extern "C" {
 	  // 	vU[nm+k*m+l] = vU[k*m+l]*1.0/Psi[l];
 	  //     }
 	  //   }else{
-	  //     F77_NAME(dsymv)(lower, &m, &one, Psi, &m, &vU[k*m], &incOne, &zero, &vU[nm+k*m], &incOne); 
+	  //     F77_NAME(dsymv)(lower, &m, &one, Psi, &m, &vU[k*m], &incOne, &zero, &vU[nm+k*m], &incOne FCONE); 
 	  //   }
 	  // }
 	  
-	  // F77_NAME(dsymv)(lower, &nm, &one, C, &nm, &vU[nm], &incOne, &zero, vU, &incOne);
+	  // F77_NAME(dsymv)(lower, &nm, &one, C, &nm, &vU[nm], &incOne, &zero, vU, &incOne FCONE);
 	  
-	  // F77_NAME(dpotrf)(lower, &nm, C, &nm, &info); if(info != 0){error("c++ error: dpotrf failed 12\n");}
+	  // F77_NAME(dpotrf)(lower, &nm, C, &nm, &info FCONE); if(info != 0){error("c++ error: dpotrf failed 12\n");}
 	  
 	  // mvrnorm(&REAL(wSamples_r)[s*nm], vU, C, nm, false);
 	  
 	}else{
-	  F77_NAME(dgemv)(ntran, &nm, &p, &negOne, X, &nm, &REAL(betaSamples_r)[s*p], &incOne, &zero, &REAL(wSamples_r)[s*nm], &incOne);
+	  F77_NAME(dgemv)(ntran, &nm, &p, &negOne, X, &nm, &REAL(betaSamples_r)[s*p], &incOne, &zero, &REAL(wSamples_r)[s*nm], &incOne FCONE);
 	  F77_NAME(daxpy)(&nm, &one, Y, &incOne, &REAL(wSamples_r)[s*nm], &incOne);
 	}
 	
